@@ -34,7 +34,7 @@
  */
 
 #include "includes.h"
-RCSID("$OpenBSD: log.c,v 1.22 2002/02/22 12:20:34 markus Exp $");
+RCSID("$OpenBSD: log.c,v 1.24 2002/07/19 15:43:33 markus Exp $");
 
 #include "log.h"
 #include "xmalloc.h"
@@ -89,6 +89,7 @@ SyslogFacility
 log_facility_number(char *name)
 {
 	int i;
+
 	if (name != NULL)
 		for (i = 0; log_facilities[i].name; i++)
 			if (strcasecmp(log_facilities[i].name, name) == 0)
@@ -100,6 +101,7 @@ LogLevel
 log_level_number(char *name)
 {
 	int i;
+
 	if (name != NULL)
 		for (i = 0; log_levels[i].name; i++)
 			if (strcasecmp(log_levels[i].name, name) == 0)
@@ -113,6 +115,7 @@ void
 error(const char *fmt,...)
 {
 	va_list args;
+
 	va_start(args, fmt);
 	do_log(SYSLOG_LEVEL_ERROR, fmt, args);
 	va_end(args);
@@ -124,6 +127,7 @@ void
 log(const char *fmt,...)
 {
 	va_list args;
+
 	va_start(args, fmt);
 	do_log(SYSLOG_LEVEL_INFO, fmt, args);
 	va_end(args);
@@ -135,6 +139,7 @@ void
 verbose(const char *fmt,...)
 {
 	va_list args;
+
 	va_start(args, fmt);
 	do_log(SYSLOG_LEVEL_VERBOSE, fmt, args);
 	va_end(args);
@@ -146,6 +151,7 @@ void
 debug(const char *fmt,...)
 {
 	va_list args;
+
 	va_start(args, fmt);
 	do_log(SYSLOG_LEVEL_DEBUG1, fmt, args);
 	va_end(args);
@@ -155,6 +161,7 @@ void
 debug2(const char *fmt,...)
 {
 	va_list args;
+
 	va_start(args, fmt);
 	do_log(SYSLOG_LEVEL_DEBUG2, fmt, args);
 	va_end(args);
@@ -164,6 +171,7 @@ void
 debug3(const char *fmt,...)
 {
 	va_list args;
+
 	va_start(args, fmt);
 	do_log(SYSLOG_LEVEL_DEBUG3, fmt, args);
 	va_end(args);
@@ -212,6 +220,18 @@ fatal_remove_cleanup(void (*proc) (void *context), void *context)
 	    (u_long) proc, (u_long) context);
 }
 
+/* Remove all cleanups, to be called after fork() */
+void
+fatal_remove_all_cleanups(void)
+{
+	struct fatal_cleanup *cu, *next_cu;
+
+	for (cu = fatal_cleanups; cu; cu = next_cu) {
+		next_cu = cu->next;
+		xfree(cu);
+	}
+}
+
 /* Cleanup and exit */
 void
 fatal_cleanup(void)
